*************
Assortativity
*************

.. automodule:: networkx.algorithms.assortativity
.. autosummary::
   :toctree: generated/

.. _networkx.algorithms.assortativity.correlation:

Assortativity
-------------
.. autosummary::
   :toctree: generated/

   degree_assortativity_coefficient
   attribute_assortativity_coefficient
   numeric_assortativity_coefficient
   degree_pearson_correlation_coefficient

.. _networkx.algorithms.assortativity.neighbor_degree:

Average neighbor degree
-----------------------
.. autosummary::
   :toctree: generated/

   average_neighbor_degree

.. _networkx.algorithms.assortativity.connectivity:

Average degree connectivity
---------------------------
.. autosummary::
   :toctree: generated/

   average_degree_connectivity

.. _networkx.algorithms.assortativity.mixing:

Mixing
------
.. autosummary::
   :toctree: generated/

   attribute_mixing_matrix
   degree_mixing_matrix
   attribute_mixing_dict
   degree_mixing_dict
   mixing_dict

.. _networkx.algorithms.assortativity.pairs:

Pairs
-----
.. autosummary::
   :toctree: generated/

   node_attribute_xy
   node_degree_xy

